@@ -5,7 +5,7 @@ import re
 import subprocess
 from concurrent.futures import ThreadPoolExecutor
 from tempfile import NamedTemporaryFile
-from typing import List, Iterator
+from typing import List, Iterator, Optional
 
 import cv2
 import numpy as np
@@ -21,11 +21,12 @@ class TesseractOCR(OCRInstance):
     """
     Tesseract-OCR instance
     """
-    def __init__(self, n_threads: int = 1, lang: str = 'eng'):
+    def __init__(self, n_threads: int = 1, lang: str = 'eng', tessdata_dir: Optional[str] = None):
         """
         Initialization of Tesseract OCR instance
         :param n_threads: number of concurrent threads used for Tesseract
         :param lang: lang parameter used in Tesseract
+        :param tessdata_dir: directory containing Tesseract traineddata files
         """
         if isinstance(n_threads, int):
             self.n_threads = n_threads
@@ -37,6 +38,26 @@ class TesseractOCR(OCRInstance):
         else:
             raise TypeError(f"Invalid type {type(lang)} for lang argument")
 
+        # Create custom environment
+        env = os.environ.copy()
+        if tessdata_dir:
+            env["TESSDATA_PREFIX"] = tessdata_dir
+        self.env = env
+
+        # Check if Tesseract is available
+        cmd_tess = subprocess.run("tesseract --version", env=self.env, shell=True)
+        if cmd_tess.returncode != 0:
+            raise EnvironmentError("Tesseract not found in environment. Check variables and PATH")
+
+        # Check if requested languages are available
+        try:
+            lang_tess = subprocess.check_output("tesseract --list-langs", env=self.env, shell=True).decode()
+            for lang in self.lang.split('+'):
+                if not any([re.search(fr"\b{lang}\b", line) is not None for line in lang_tess.splitlines()]):
+                    raise EnvironmentError(f"Tesseract '{lang}' trainned data cannot be located")
+        except subprocess.CalledProcessError:
+            raise EnvironmentError("Tesseract trainned data cannot be located.")
+
     def hocr(self, image: np.ndarray) -> str:
         """
         Get hOCR HTML of an image using Tesseract
@@ -50,6 +71,7 @@ class TesseractOCR(OCRInstance):
 
             # Get hOCR
             hocr = subprocess.check_output(f"tesseract {tmp_file} stdout --psm 11 -l {self.lang} hocr",
+                                           env=self.env,
                                            stderr=subprocess.STDOUT,
                                            shell=True)
 
